@@ -23,6 +23,10 @@ A concept (CUI) or a term from the Unified Medical Language System
 
 =head2 Optional Arguments:
 
+=head3 --debug 
+
+Sets the debug flag for testing
+
 =head3 --username STRING
 
 Username is required to access the umls database on MySql
@@ -117,7 +121,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s" );
+GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s" );
 
 
 #  if help is defined, print out help
@@ -157,6 +161,9 @@ if(defined $opt_config) {
 if(defined $opt_verbose) {
     $option_hash{"verbose"} = $opt_verbose;
 }
+if(defined $opt_debug) {
+    $option_hash{"debug"} = $opt_debug;
+}
 if(defined $opt_username) {
     $option_hash{"username"} = $opt_username;
 }
@@ -264,6 +271,8 @@ sub showHelp() {
 
     print "Options:\n\n";
 
+    print "--debug                  Set the debug flag for testing\n\n";
+
     print "--username STRING        Username required to access mysql\n\n";
 
     print "--password STRING        Password required to access mysql\n\n";
@@ -285,7 +294,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getParents.pl,v 1.4 2010/01/07 23:15:44 btmcinnes Exp $';
+    print '$Id: getParents.pl,v 1.5 2010/01/20 16:28:31 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
